''' Etag: W/"32f-ocZpOyPZZyg+7TCyJEV3si5izKM" HTTP/1.1 200 OK Access-Control-Allow-Origin: * Content-Type: text/html Cache-Control: no-cache Date: Fri, 12 Jan 2024 04:19:18 GMT Connection: keep-alive Keep-Alive: timeout=5 Content-Length: 815 #"Expires": "Fri, 19 Jan 2024 04:25:05 GMT", #"Cache-Control": "no-cache, no-store, must-revalidate", #"Pragma": "no-cache", #"Expires": "0" ''' ''' "ETag": "habitat", "Cache-Control": "no-cache" ''' ''' Cache-Control: no-cache, no-store, must-revalidate Pragma: no-cache Expires: 0 '''